# brainglobe-utils
Shared general purpose tools for the BrainGlobe project

## Installation

```bash
pip install brainglobe-utils
```
To also include the dependencies required for `napari`, use:
```bash
pip install brainglobe-utils[napari]
```

For development, clone this repository and install the dependencies with one of the following commands:
```bash
pip install -e .[dev]
pip install -e .[dev,napari]
```
